==> eea.geotags-10.5.zip: eea.geotags-10.5/eea/geotags/vocabularies/data/groups.py <==
""" Geotags Tree vocabulary
"""
VOC = {('geotags', 'Geotags Tree'): {('efta4', 'EFTA4'): {
    ('geo-2629691', 'Iceland'): {},
    ('geo-2658434', 'Switzerland'): {},
    ('geo-3042058', 'Liechtenstein'): {},
    ('geo-3144096', 'Norway'): {}},

                                     ('eu15', 'EU15'): {
    ('geo-2264397', 'Portugal'): {},
    ('geo-2510769', 'Spain'): {},
    ('geo-2623032', 'Denmark'): {},
    ('geo-2635167', 'United Kingdom'): {},
    ('geo-2661886', 'Sweden'): {},
    ('geo-2750405', 'Netherlands'): {},
    ('geo-2782113', 'Austria'): {},
    ('geo-2802361', 'Belgium'): {},
    ('geo-2921044', 'Germany'): {},
    ('geo-2960313', 'Luxembourg'): {},
    ('geo-2963597', 'Ireland'): {},
    ('geo-3017382', 'France'): {},
    ('geo-3175395', 'Italy'): {},
    ('geo-390903', 'Greece'): {},
    ('geo-660013', 'Finland'): {}},

                                     ('eu25', 'EU25'): {
    ('geo-146669', 'Cyprus'): {},
    ('geo-2264397', 'Portugal'): {},
    ('geo-2510769', 'Spain'): {},
    ('geo-2562770', 'Malta'): {},
    ('geo-2623032', 'Denmark'): {},
    ('geo-2635167', 'United Kingdom'): {},
    ('geo-2661886', 'Sweden'): {},
    ('geo-2750405', 'Netherlands'): {},
    ('geo-2782113', 'Austria'): {},
    ('geo-2802361', 'Belgium'): {},
    ('geo-2921044', 'Germany'): {},
    ('geo-2960313', 'Luxembourg'): {},
    ('geo-2963597', 'Ireland'): {},
    ('geo-3017382', 'France'): {},
    ('geo-3057568', 'Slovakia'): {},
    ('geo-3077311', 'Czech Republic'): {},
    ('geo-3175395', 'Italy'): {},
    ('geo-3190538', 'Slovenia'): {},
    ('geo-390903', 'Greece'): {},
    ('geo-453733', 'Estonia'): {},
    ('geo-458258', 'Latvia'): {},
    ('geo-597427', 'Lithuania'): {},
    ('geo-660013', 'Finland'): {},
    ('geo-719819', 'Hungary'): {},
    ('geo-798544', 'Poland'): {}},

                                     ('eu27', 'EU27'): {
    ('geo-146669', 'Cyprus'): {},
    ('geo-2264397', 'Portugal'): {},
    ('geo-2510769', 'Spain'): {},
    ('geo-2562770', 'Malta'): {},
    ('geo-2623032', 'Denmark'): {},
    ('geo-2635167', 'United Kingdom'): {},
    ('geo-2661886', 'Sweden'): {},
    ('geo-2750405', 'Netherlands'): {},
    ('geo-2782113', 'Austria'): {},
    ('geo-2802361', 'Belgium'): {},
    ('geo-2921044', 'Germany'): {},
    ('geo-2960313', 'Luxembourg'): {},
    ('geo-2963597', 'Ireland'): {},
    ('geo-3017382', 'France'): {},
    ('geo-3057568', 'Slovakia'): {},
    ('geo-3077311', 'Czech Republic'): {},
    ('geo-3175395', 'Italy'): {},
    ('geo-3190538', 'Slovenia'): {},
    ('geo-390903', 'Greece'): {},
    ('geo-453733', 'Estonia'): {},
    ('geo-458258', 'Latvia'): {},
    ('geo-597427', 'Lithuania'): {},
    ('geo-660013', 'Finland'): {},
    ('geo-719819', 'Hungary'): {},
    ('geo-732800', 'Bulgaria'): {},
    ('geo-798544', 'Poland'): {},
    ('geo-798549', 'Romania'): {}}}}

==> eea.geotags-11.8.zip: eea.geotags-11.8/eea/geotags/vocabularies/data/groups.py <==
""" Geotags Tree vocabulary
"""
VOC = {('geotags', 'Geotags Tree'): {('efta4', 'EFTA4'): {
    ('geo-2629691', 'Iceland'): {},
    ('geo-2658434', 'Switzerland'): {},
    ('geo-3042058', 'Liechtenstein'): {},
    ('geo-3144096', 'Norway'): {}},

                                     ('eu15', 'EU15'): {
    ('geo-2264397', 'Portugal'): {},
    ('geo-2510769', 'Spain'): {},
    ('geo-2623032', 'Denmark'): {},
    ('geo-2635167', 'United Kingdom'): {},
    ('geo-2661886', 'Sweden'): {},
    ('geo-2750405', 'Netherlands'): {},
    ('geo-2782113', 'Austria'): {},
    ('geo-2802361', 'Belgium'): {},
    ('geo-2921044', 'Germany'): {},
    ('geo-2960313', 'Luxembourg'): {},
    ('geo-2963597', 'Ireland'): {},
    ('geo-3017382', 'France'): {},
    ('geo-3175395', 'Italy'): {},
    ('geo-390903', 'Greece'): {},
    ('geo-660013', 'Finland'): {}},

                                     ('eu25', 'EU25'): {
    ('geo-146669', 'Cyprus'): {},
    ('geo-2264397', 'Portugal'): {},
    ('geo-2510769', 'Spain'): {},
    ('geo-2562770', 'Malta'): {},
    ('geo-2623032', 'Denmark'): {},
    ('geo-2635167', 'United Kingdom'): {},
    ('geo-2661886', 'Sweden'): {},
    ('geo-2750405', 'Netherlands'): {},
    ('geo-2782113', 'Austria'): {},
    ('geo-2802361', 'Belgium'): {},
    ('geo-2921044', 'Germany'): {},
    ('geo-2960313', 'Luxembourg'): {},
    ('geo-2963597', 'Ireland'): {},
    ('geo-3017382', 'France'): {},
    ('geo-3057568', 'Slovakia'): {},
    ('geo-3077311', 'Czechia'): {},
    ('geo-3175395', 'Italy'): {},
    ('geo-3190538', 'Slovenia'): {},
    ('geo-390903', 'Greece'): {},
    ('geo-453733', 'Estonia'): {},
    ('geo-458258', 'Latvia'): {},
    ('geo-597427', 'Lithuania'): {},
    ('geo-660013', 'Finland'): {},
    ('geo-719819', 'Hungary'): {},
    ('geo-798544', 'Poland'): {}},

                                     ('eu27', 'EU27'): {
    ('geo-146669', 'Cyprus'): {},
    ('geo-2264397', 'Portugal'): {},
    ('geo-2510769', 'Spain'): {},
    ('geo-2562770', 'Malta'): {},
    ('geo-2623032', 'Denmark'): {},
    ('geo-2635167', 'United Kingdom'): {},
    ('geo-2661886', 'Sweden'): {},
    ('geo-2750405', 'Netherlands'): {},
    ('geo-2782113', 'Austria'): {},
    ('geo-2802361', 'Belgium'): {},
    ('geo-2921044', 'Germany'): {},
    ('geo-2960313', 'Luxembourg'): {},
    ('geo-2963597', 'Ireland'): {},
    ('geo-3017382', 'France'): {},
    ('geo-3057568', 'Slovakia'): {},
    ('geo-3077311', 'Czechia'): {},
    ('geo-3175395', 'Italy'): {},
    ('geo-3190538', 'Slovenia'): {},
    ('geo-390903', 'Greece'): {},
    ('geo-453733', 'Estonia'): {},
    ('geo-458258', 'Latvia'): {},
    ('geo-597427', 'Lithuania'): {},
    ('geo-660013', 'Finland'): {},
    ('geo-719819', 'Hungary'): {},
    ('geo-732800', 'Bulgaria'): {},
    ('geo-798544', 'Poland'): {},
    ('geo-798549', 'Romania'): {}}}}
